<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 12/10/2005 *
 * ===================                          Last change: 06/20/2010 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : daily_holiday.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Things to be done on daily reset                 *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Dinge, die beim taeglichen Reset erledigt werden *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif ((!isHtmlOutputMode()) || ((!isDailyResetEnabled()) && (getConfig('holiday_mode') == 'RESET'))) {
	// Do not execute when script is in non-HTML mode or no daily reset
	return;
} elseif (!isExtensionActive('holiday')) {
	if (isDebugModeEnabled()) logDebugMessage(__FILE__, __LINE__, 'Not resetting, needed extension ext-holiday disabled.');
	return;
}

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset started.');

// Check for holidays we need to enable and send email to user
$result_main = sqlQuery("SELECT
	`userid`,
	`holiday_activated`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`holiday_activated` > 0 AND
	`holiday_activated` < UNIX_TIMESTAMP() AND
	`holiday_active`='N'
ORDER BY
	`holiday_activated` ASC",
__FILE__, __LINE__);

// Entries found?
if (!ifSqlHasZeroNumRows($result_main)) {
	// Init SQLs
	initSqls();

	// We have found at least one useraccount so let's check it...
	while ($content = sqlFetchArray($result_main)) {
		// Check if his holiday can be activated
		$result_holiday = sqlQueryEscaped("SELECT
	`holiday_start`,
	`holiday_end`
FROM
	`{?_MYSQL_PREFIX?}_user_holidays`
WHERE
	`userid`=%s AND
	`holiday_start` <= UNIX_TIMESTAMP() AND
	`holiday_end` > UNIX_TIMESTAMP()
LIMIT 1",
			array(bigintval($content['userid'])), __FILE__, __LINE__);

		// Is there an entry?
		if (sqlNumRows($result_holiday) == 1) {
			// Okay, this user can be send away to holiday...
			$content = merge_array($content, sqlFetchArray($result_holiday));

			// Prepare all data for the template
			$content = merge_array($content, array(
				'activated' => generateDateTime($content['holiday_activated'], 1),
				'start'     => generateDateTime($content['holiday_start']    , 1),
				'end'       => generateDateTime($content['holiday_end']      , 1)
			));

			// Send email to user
			$message = loadEmailTemplate('member_holiday_activated', $content, $content['userid']);
			sendEmail($content['userid'], '{--MEMBER_HOLIDAY_ACTIVATED_SUBJECT--}', $message);

			// Update account
			addSql(sqlQueryEscaped("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`holiday_active`='Y'
WHERE
	`userid`=%s
LIMIT 1",
				array(bigintval($content['userid'])), __FILE__, __LINE__, FALSE));
		} // END - if

		// Free memory
		sqlFreeResult($result_holiday);
	} // END - while

	// Run all SQLs
	runFilterChain('run_sqls');
} // END - if

// Free memory
sqlFreeResult($result_main);

// Stop currently activated holidays
stopHolidays();

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset ended.');

// [EOF]
?>
