<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/29/2003 *
 * ===================                          Last change: 04/17/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : loader.php                                       *
 * -------------------------------------------------------------------- *
 * Short description : De-referrer page                                 *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Referrer neu setzen                              *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} // END - if

// Is an URL specified?
if ((isGetRequestElementSet('url')) && (isGetRequestElementSet('hash')) && (isGetRequestElementSet('salt'))) {
	// Decode URL
	$decodedUrl = decodeString(str_replace(' ', '+', compileUriCode(urldecode(getRequestElement('url')))));

	// Debug message
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'decodedUrl=' . $decodedUrl . ',hash=' . getRequestElement('hash'));

	// Generate hash for comparing it
	$hash = encodeHashForCookie(generateHash($decodedUrl . getSiteKey() . getDateKey(), getRequestElement('salt')));

	// Debug message
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'decodedUrl=' . $decodedUrl . ',hash=' . $hash);

	// Validate the URL and hash
	if ($hash != getRequestElement('hash')) {
		// Hash doesn't match
		displayMessage('{--LOADER_SECURITY_HASH_MISMATCH--}');

		// Log this event
		logDebugMessage(__FILE__, __LINE__, 'Hash ' . getRequestElement('hash') . ' does not match URL ' . $decodedUrl);
	} elseif (isUrlValid($decodedUrl)) {
		// Generate a JavaScript that redirects us
		loadTemplate('loader', FALSE, $decodedUrl);
	} else {
		// URL invalid
		redirectToUrl('modules.php?module=index');
	}
} else {
	// Is the hash not provided?
	if (!isGetRequestElementSet('hash')) {
		// Very old (external!) call
		logDebugMessage(__FUNCTION__, __LINE__, 'Possible old call on loader.php detected. Redirecting to index.php anyway ...');
	} // END - if

	// Invalid or no URL entered!
	redirectToUrl('modules.php?module=index');
}

// [EOF]
?>
