<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 03/20/2005 *
 * ===================                          Last change: 03/20/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-themes.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Theme selection for members                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Design-Auswahl fuer Mitglieder                   *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} elseif (!isMember()) {
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

if ((!isExtensionActive('theme')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=theme%}');
	return;
} // END - if

if (isPostRequestElementSet('member_theme')) {
	// Save theme to member's profile
	sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `curr_theme`='%s' WHERE `userid`=%s LIMIT 1",
		array(
			postRequestElement('member_theme'),
			getMemberId()
		), __FILE__, __LINE__);

	// Set new theme for guests
	$newTheme = sqlEscapeString(postRequestElement('member_theme'));

	// Change to new theme
	setMailerTheme($newTheme);

	// Theme saved!
	displayMessage('{--MEMBER_THEME_SAVED--}');
} // END - if

// Initialize array
$themes = array(
	'theme_unix'    => array(), // Unix name from filesystem
	'theme_name'    => array(), // Title
	'theme_author'  => array(), // Theme author's name
	'theme_email'   => array(), // Author's email address
	'theme_url'     => array(), // URL were you can download it from
	'theme_version' => array(), // Version number of theme
);

// Read directory "themes"
$includes = getArrayFromDirectory('theme/', '', FALSE, TRUE, array('css', 'images'));

// Walk through all entries and add it
foreach ($includes as $inc) {
	// Get directory from it
	$dir = basename(dirname($inc));

	// Is the theme active, then include it
	if (isThemeActive($dir)) {
		// Found a valid directory so let's load it's theme.php file
		loadInclude($inc);

		// Add found theme to array
		array_push($themes['theme_unix']   , $dir);
		array_push($themes['theme_name']   , $GLOBALS['theme_data']['name']);
		array_push($themes['theme_author'] , $GLOBALS['theme_data']['author']);
		array_push($themes['theme_email']  , $GLOBALS['theme_data']['email']);
		array_push($themes['theme_url']    , $GLOBALS['theme_data']['url']);
		array_push($themes['theme_version'], $GLOBALS['theme_data']['version']);
	} // END - if
} // END - while

// Remove last theme data
unset($GLOBALS['theme_data']);

// Sort array by Uni* name
array_pk_sort($themes, array('theme_name'));

// Generate output lines for the template
$OUT = '';
foreach ($themes['theme_unix'] as $key => $unix) {
	$default = '';
	if (getCurrentTheme() == $unix) {
		$default = ' checked="checked"';
	} // END - if

	// Prepare content
	$content = array(
		'unix'          => $unix,
		'default'       => $default,
		'theme_name'    => $themes['theme_name'][$key],
		'theme_email'   => $themes['theme_email'][$key],
		'theme_author'  => $themes['theme_author'][$key],
		'theme_url'     => $themes['theme_url'][$key],
		'theme_version' => $themes['theme_version'][$key]
	);

	// Load row template
	$OUT .= loadTemplate('member_themes_row', TRUE, $content);
} // END - foreach

if (empty($OUT)) {
	// No themes found???
	$OUT = '<tr>
  <td colspan="5" class="bottom" height="80">
    ' . displayMessage('{--MEMBER_NO_THEMES_FOUND--}', TRUE) . '
  </td>
</tr>';
} // END - if

// Load template
loadTemplate('member_themes', FALSE, $OUT);

// [EOF]
?>
